@@ -5,15 +5,6 @@
 
 #include "spvm_base.h"
 
-enum {
-  SPVM_BASIC_TYPE_C_CATEGORY_UNKNOWN,
-  SPVM_BASIC_TYPE_C_CATEGORY_VOID,
-  SPVM_BASIC_TYPE_C_CATEGORY_UNDEF,
-  SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC,
-  SPVM_BASIC_TYPE_C_CATEGORY_ANY_OBJECT,
-  SPVM_BASIC_TYPE_C_CATEGORY_PACKAGE,
-};
-
 enum {
   SPVM_BASIC_TYPE_C_ID_UNKNOWN,
   SPVM_BASIC_TYPE_C_ID_VOID,
@@ -28,12 +19,10 @@ enum {
   SPVM_BASIC_TYPE_C_ID_STRING,
 };
 
-extern const char* const SPVM_BASIC_TYPE_C_CATEGORY_NAMES[];
 extern const char* const SPVM_BASIC_TYPE_C_ID_NAMES[];
 
 struct SPVM_basic_type {
   const char* name;
-  int32_t category;
   int32_t id;
 };
 
