@@ -23,6 +23,7 @@
 #include "spvm_api.h"
 #include "spvm_opcode.h"
 #include "spvm_basic_type.h"
+#include "spvm_use.h"
 
 SPVM_RUNTIME* SPVM_COMPILER_new_runtime(SPVM_COMPILER* compiler) {
   
@@ -44,38 +45,35 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
 
   // Allocator
   compiler->allocator = SPVM_COMPILER_ALLOCATOR_new(compiler);
-  
-  // Parser information
-  compiler->op_sub_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-  compiler->op_packages = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  
-  compiler->op_package_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-  compiler->op_our_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-  compiler->op_types = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  compiler->op_use_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-  compiler->op_use_stack = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  compiler->include_pathes = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
+
   compiler->bufptr = "";
-  compiler->basic_types = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  compiler->basic_type_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-  compiler->op_constants = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  compiler->op_subs = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
 
-  compiler->method_signatures = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  compiler->method_signature_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
+  compiler->name_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
 
-  compiler->package_load_path_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-
-  compiler->basic_type_name_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, compiler->allocator, 0);
-
-  // Bytecodes
+  // Parser information
+  compiler->op_use_stack = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  compiler->op_types = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  compiler->basic_types = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  compiler->basic_type_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  compiler->op_subs = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  compiler->op_sub_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  compiler->op_packages = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  compiler->op_package_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  compiler->op_our_symtable = SPVM_COMPILER_ALLOCATOR_alloc_hash(compiler, 0);
+  compiler->op_constants = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  compiler->module_include_pathes = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
   compiler->opcode_array = SPVM_OPCODE_ARRAY_new(compiler);
   
-  compiler->const_string_symtable = SPVM_HASH_new(0);
-  
   // Add basic types
   SPVM_COMPILER_add_basic_types(compiler);
 
+  // use String module
+  SPVM_OP* op_name_string = SPVM_OP_new_op_name(compiler, "String", "Std", 0);
+  SPVM_OP* op_type_string = SPVM_OP_build_basic_type(compiler, op_name_string);
+  SPVM_OP* op_use_string = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_USE, "Std", 0);
+  SPVM_OP_build_use(compiler, op_use_string, op_type_string);
+  SPVM_LIST_push(compiler->op_use_stack, op_use_string);
+  
   return compiler;
 }
 
@@ -84,7 +82,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_UNKNOWN;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_UNKNOWN;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -94,7 +91,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_VOID;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_VOID;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -104,7 +100,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_UNDEF;
-     basic_type->category = SPVM_BASIC_TYPE_C_ID_UNDEF;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -114,7 +109,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_BYTE;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -124,7 +118,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_SHORT;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -134,7 +127,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_INT;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -144,7 +136,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_LONG;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -154,7 +145,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_FLOAT;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -164,7 +154,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_DOUBLE;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_NUMERIC;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -174,7 +163,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_ANY_OBJECT;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_ANY_OBJECT;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -184,7 +172,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   {
      SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
      basic_type->id = SPVM_BASIC_TYPE_C_ID_STRING;
-     basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_PACKAGE;
      basic_type->name = SPVM_BASIC_TYPE_C_ID_NAMES[basic_type->id];
      SPVM_LIST_push(compiler->basic_types, basic_type);
      SPVM_HASH_insert(compiler->basic_type_symtable, basic_type->name, strlen(basic_type->name), basic_type);
@@ -193,29 +180,6 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
 
 int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler) {
   
-  const char* entyr_point_package_name = compiler->entry_point_package_name;
-  
-  if (entyr_point_package_name) {
-    // Create use op for entry point package
-    SPVM_OP* op_use_entry_point = SPVM_OP_new_op_use_from_package_name(compiler, entyr_point_package_name, "main", 1);
-    SPVM_LIST_push(compiler->op_use_stack, op_use_entry_point);
-    SPVM_HASH_insert(compiler->op_use_symtable, entyr_point_package_name, strlen(entyr_point_package_name), op_use_entry_point);
-    
-    // Entry point
-    int32_t entyr_point_package_name_length = (int32_t)strlen(entyr_point_package_name);
-    int32_t entry_point_sub_name_length =  (int32_t)(entyr_point_package_name_length + 6);
-    char* entry_point_sub_name = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(entry_point_sub_name_length + 1);
-    strncpy(entry_point_sub_name, entyr_point_package_name, entyr_point_package_name_length);
-    strncpy(entry_point_sub_name + entyr_point_package_name_length, "::main", 6);
-    entry_point_sub_name[entry_point_sub_name_length] = '\0';
-    compiler->entry_point_sub_name = entry_point_sub_name;
-  }
-  
-  // use String module
-  SPVM_OP* op_use_string = SPVM_OP_new_op_use_from_package_name(compiler, "String", "Std", 0);
-  SPVM_LIST_push(compiler->op_use_stack, op_use_string);
-  SPVM_HASH_insert(compiler->op_use_symtable, "String", strlen("String"), op_use_string);
-  
   /* call SPVM_yyparse */
   int32_t parse_success = SPVM_yyparse(compiler);
   
@@ -225,7 +189,7 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler) {
 void SPVM_COMPILER_free(SPVM_COMPILER* compiler) {
   
   // Free allocator
-  SPVM_COMPILER_ALLOCATOR_free(compiler, compiler->allocator);
+  SPVM_COMPILER_ALLOCATOR_free(compiler);
   
   // Free opcode array
   SPVM_OPCODE_ARRAY_free(compiler, compiler->opcode_array);
