@@ -123,6 +123,7 @@ const char* const SPVM_OP_C_ID_NAMES[] = {
   "FLOAT",
   "DOUBLE",
   "STRING",
+  "OBJECT",
   "WEAKEN",
   "WEAKEN_FIELD",
   "SPECIAL_ASSIGN",
@@ -149,7 +150,7 @@ const char* const SPVM_OP_C_ID_NAMES[] = {
 SPVM_OP* SPVM_OP_new_op_var_tmp(SPVM_COMPILER* compiler, SPVM_OP* op_sub, SPVM_TYPE* type, const char* file, int32_t line) {
 
   // Temparary variable name
-  char* name = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, compiler->allocator, strlen("@tmp2147483647"));
+  char* name = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, strlen("@tmp2147483647"));
   sprintf(name, "@tmp%d", compiler->tmp_var_length);
   compiler->tmp_var_length++;
   SPVM_OP* op_name = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_NAME, file, line);
@@ -177,7 +178,7 @@ void SPVM_OP_apply_unary_numeric_promotion(SPVM_COMPILER* compiler, SPVM_OP* op_
   
   SPVM_TYPE* dist_type;
   if (type->dimension == 0 && type->basic_type->id <= SPVM_BASIC_TYPE_C_ID_INT) {
-    dist_type = SPVM_TYPE_get_int_type(compiler);
+    dist_type = SPVM_TYPE_create_int_type(compiler);
   }
   else {
     return;
@@ -202,16 +203,16 @@ void SPVM_OP_apply_binary_numeric_promotion(SPVM_COMPILER* compiler, SPVM_OP* op
   
   SPVM_TYPE* dist_type;
   if ((first_type->dimension == 0 && first_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_DOUBLE) || (last_type->dimension == 0 && last_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_DOUBLE)) {
-    dist_type = SPVM_TYPE_get_double_type(compiler);
+    dist_type = SPVM_TYPE_create_double_type(compiler);
   }
   else if ((first_type->dimension == 0 && first_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_FLOAT) || (last_type->dimension == 0 && last_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_FLOAT)) {
-    dist_type = SPVM_TYPE_get_float_type(compiler);
+    dist_type = SPVM_TYPE_create_float_type(compiler);
   }
   else if ((first_type->dimension == 0 && first_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_LONG) || (last_type->dimension == 0 && last_type->basic_type->id == SPVM_BASIC_TYPE_C_ID_LONG)) {
-    dist_type = SPVM_TYPE_get_long_type(compiler);
+    dist_type = SPVM_TYPE_create_long_type(compiler);
   }
   else {
-    dist_type = SPVM_TYPE_get_int_type(compiler);
+    dist_type = SPVM_TYPE_create_int_type(compiler);
   }
   
   if (!(first_type->basic_type->id == dist_type->basic_type->id && first_type->dimension == dist_type->dimension)) {
@@ -573,25 +574,12 @@ SPVM_OP* SPVM_OP_build_constant(SPVM_COMPILER* compiler, SPVM_OP* op_constant) {
   }
 }
 
-SPVM_OP* SPVM_OP_new_op_use_from_package_name(SPVM_COMPILER* compiler, const char* package_name, const char* file, int32_t line) {
-
-  SPVM_OP* op_name_package = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_NAME, file, line);
-  op_name_package->uv.name = package_name;
-  SPVM_OP* op_use = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_USE, file, line);
-  SPVM_USE* use = SPVM_USE_new(compiler);
-  use->package_name = package_name;
-  op_use->uv.use = use;
-  SPVM_OP_insert_child(compiler, op_use, op_use->last, op_name_package);
-  
-  return op_use;
-}
-
 SPVM_OP* SPVM_OP_new_op_constant_byte(SPVM_COMPILER* compiler, int8_t value, const char* file, int32_t line) {
   SPVM_OP* op_constant = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_CONSTANT, file, line);
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   
   constant->value.byte_value = value;
-  constant->type = SPVM_TYPE_get_byte_type(compiler);
+  constant->type = SPVM_TYPE_create_byte_type(compiler);
   
   op_constant->uv.constant = constant;
 
@@ -605,7 +593,7 @@ SPVM_OP* SPVM_OP_new_op_constant_short(SPVM_COMPILER* compiler, int16_t value, c
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   
   constant->value.short_value = value;
-  constant->type = SPVM_TYPE_get_short_type(compiler);
+  constant->type = SPVM_TYPE_create_short_type(compiler);
   
   op_constant->uv.constant = constant;
 
@@ -619,7 +607,7 @@ SPVM_OP* SPVM_OP_new_op_constant_int(SPVM_COMPILER* compiler, int32_t value, con
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   
   constant->value.int_value = value;
-  constant->type = SPVM_TYPE_get_int_type(compiler);
+  constant->type = SPVM_TYPE_create_int_type(compiler);
   
   op_constant->uv.constant = constant;
 
@@ -633,7 +621,7 @@ SPVM_OP* SPVM_OP_new_op_constant_long(SPVM_COMPILER* compiler, int64_t value, co
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   
   constant->value.long_value = value;
-  constant->type = SPVM_TYPE_get_long_type(compiler);
+  constant->type = SPVM_TYPE_create_long_type(compiler);
   
   op_constant->uv.constant = constant;
 
@@ -647,7 +635,7 @@ SPVM_OP* SPVM_OP_new_op_constant_float(SPVM_COMPILER* compiler, float value, con
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   
   constant->value.float_value = value;
-  constant->type = SPVM_TYPE_get_float_type(compiler);
+  constant->type = SPVM_TYPE_create_float_type(compiler);
   
   op_constant->uv.constant = constant;
 
@@ -661,7 +649,7 @@ SPVM_OP* SPVM_OP_new_op_constant_double(SPVM_COMPILER* compiler, double value, c
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   
   constant->value.double_value = value;
-  constant->type = SPVM_TYPE_get_double_type(compiler);
+  constant->type = SPVM_TYPE_create_double_type(compiler);
   
   op_constant->uv.constant = constant;
   
@@ -675,7 +663,7 @@ SPVM_OP* SPVM_OP_new_op_constant_string(SPVM_COMPILER* compiler, char* string, i
   SPVM_OP* op_constant = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_CONSTANT, file, line);
   SPVM_CONSTANT* constant = SPVM_CONSTANT_new(compiler);
   constant->value.string_value = string;
-  constant->type = SPVM_TYPE_get_string_type(compiler);
+  constant->type = SPVM_TYPE_create_string_type(compiler);
   constant->string_length = length;
   op_constant->uv.constant = constant;
   
@@ -1119,7 +1107,6 @@ SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
   switch (op->id) {
     case SPVM_OP_C_ID_PACKAGE: {
       SPVM_PACKAGE* package = op->uv.package;
-      const char* package_name = package->op_name->uv.name;
       type = package->op_type->uv.type;
       break;
     }
@@ -1137,13 +1124,13 @@ SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
     case SPVM_OP_C_ID_STRING_LT:
     case SPVM_OP_C_ID_STRING_LE:
     case SPVM_OP_C_ID_ISA:
-      type = SPVM_TYPE_get_int_type(compiler);
+      type = SPVM_TYPE_create_int_type(compiler);
       break;
     case SPVM_OP_C_ID_CONCAT:
-      type = SPVM_TYPE_get_string_type(compiler);
+      type = SPVM_TYPE_create_string_type(compiler);
       break;
     case SPVM_OP_C_ID_ARRAY_LENGTH:
-      type = SPVM_TYPE_get_int_type(compiler);
+      type = SPVM_TYPE_create_int_type(compiler);
       break;
     case SPVM_OP_C_ID_ARRAY_ACCESS: {
       SPVM_TYPE* first_type = SPVM_OP_get_type(compiler, op->first);
@@ -1211,7 +1198,7 @@ SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
       break;
     }
     case SPVM_OP_C_ID_UNDEF : {
-      type = SPVM_TYPE_get_undef_type(compiler);
+      type = SPVM_TYPE_create_undef_type(compiler);
       break;
     }
     case SPVM_OP_C_ID_CONSTANT: {
@@ -1234,7 +1221,7 @@ SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
       break;
     }
     case SPVM_OP_C_ID_EXCEPTION_VAR: {
-      type = SPVM_TYPE_get_string_type(compiler);
+      type = SPVM_TYPE_create_string_type(compiler);
       break;
     }
     case SPVM_OP_C_ID_MY: {
@@ -1437,7 +1424,7 @@ SPVM_OP* SPVM_OP_build_grammar(SPVM_COMPILER* compiler, SPVM_OP* op_packages) {
 const char* SPVM_OP_create_abs_name(SPVM_COMPILER* compiler, const char* package_name, const char* name) {
   int32_t length = (int32_t)(strlen(package_name) + 2 + strlen(name));
   
-  char* abs_name = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, compiler->allocator, length);
+  char* abs_name = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, length);
   
   sprintf(abs_name, "%s::%s", package_name, name);
   
@@ -1489,7 +1476,7 @@ const char* SPVM_OP_create_method_signature(SPVM_COMPILER* compiler, SPVM_SUB* s
     length += 1;
   }
   
-  char* method_signature = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, compiler->allocator, length);
+  char* method_signature = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, length);
   
   // Calcurate signature length
   char* bufptr = method_signature;
@@ -1556,7 +1543,7 @@ const char* SPVM_OP_create_method_signature(SPVM_COMPILER* compiler, SPVM_SUB* s
 const char* SPVM_OP_create_package_var_abs_name(SPVM_COMPILER* compiler, const char* package_name, const char* name) {
   int32_t length = (int32_t)(strlen(package_name) + 2 + strlen(name));
   
-  char* abs_name = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, compiler->allocator, length);
+  char* abs_name = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, length);
   
   sprintf(abs_name, "$%s::%s", package_name, &name[1]);
   
@@ -1564,16 +1551,23 @@ const char* SPVM_OP_create_package_var_abs_name(SPVM_COMPILER* compiler, const c
 }
 
 SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPVM_OP* op_type, SPVM_OP* op_block, SPVM_OP* op_list_descriptors) {
-  
+
+  SPVM_LIST* op_fields = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  SPVM_LIST* op_subs = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  SPVM_LIST* op_ours = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+  SPVM_LIST* object_field_ids = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, 0);
+
   // Package
   SPVM_PACKAGE* package = SPVM_PACKAGE_new(compiler);
   
+  package->load_path = compiler->cur_file;
+  
   if (!op_type) {
     // Package is anon
     package->is_anon = 1;
     
     // Anon package name
-    char* name_package = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, compiler->allocator, strlen("@anon2147483647"));
+    char* name_package = SPVM_COMPILER_ALLOCATOR_alloc_string(compiler, strlen("@anon2147483647"));
     sprintf(name_package, "@anon%d", compiler->anon_package_length);
     compiler->anon_package_length++;
     SPVM_OP* op_name_package = SPVM_OP_new_op_name(compiler, name_package, op_package->file, op_package->line);
@@ -1619,13 +1613,6 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
     }
   }
   
-  // Type(type is same as package name)
-  SPVM_TYPE* type_package = SPVM_TYPE_new(compiler);
-  
-  SPVM_LIST* op_fields = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  SPVM_LIST* op_subs = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  SPVM_LIST* op_ours = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
-  
   SPVM_OP* op_decls = op_block->first;
   SPVM_OP* op_decl = op_decls->first;
   while ((op_decl = SPVM_OP_sibling(compiler, op_decl))) {
@@ -1667,6 +1654,7 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
       SPVM_OP* op_field = SPVM_LIST_fetch(op_fields, i);
       
       SPVM_FIELD* field = op_field->uv.field;
+      field->id = i;
       const char* field_name = field->op_name->uv.name;
       
       SPVM_OP* found_op_field = SPVM_HASH_search(package->op_field_symtable, field_name, strlen(field_name));
@@ -1685,11 +1673,15 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
         
         // Add op package
         field->op_package = op_package;
-        
-        
+      }
+      
+      if (SPVM_TYPE_is_object(compiler, field->op_type->uv.type)) {
+        SPVM_LIST_push(object_field_ids, (void*)(intptr_t)field->id);
       }
     }
   }
+  
+  package->object_field_ids = object_field_ids;
 
   // Register package variable
   {
@@ -1727,10 +1719,6 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
     }
   }
   
-  // Add package load path
-  const char* package_load_path = SPVM_HASH_search(compiler->package_load_path_symtable, package_name, strlen(package_name));
-  package->load_path = (char*)package_load_path;
-  
   // Add package
   op_package->uv.package = package;
   
@@ -1807,14 +1795,6 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
           const char* method_signature = SPVM_OP_create_method_signature(compiler, sub);
           sub->method_signature = method_signature;
           SPVM_HASH_insert(sub->op_package->uv.package->method_signature_symtable, method_signature, strlen(method_signature), sub);
-          
-          int32_t* found_index_ptr = SPVM_HASH_search(compiler->method_signature_symtable, method_signature, strlen(method_signature));
-          if (!found_index_ptr) {
-            SPVM_LIST_push(compiler->method_signatures, (char*)method_signature);
-            int32_t* new_found_index_ptr = SPVM_COMPILER_ALLOCATOR_alloc_int(compiler, compiler->allocator);
-            *new_found_index_ptr = compiler->method_signatures->length - 1;
-            SPVM_HASH_insert(compiler->method_signature_symtable, method_signature, strlen(method_signature), new_found_index_ptr);
-          }
         }
         
         SPVM_LIST_push(compiler->op_subs, op_sub);
@@ -1830,7 +1810,7 @@ SPVM_OP* SPVM_OP_build_package(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPV
   package->id = compiler->op_packages->length;
   SPVM_LIST_push(compiler->op_packages, op_package);
   SPVM_HASH_insert(compiler->op_package_symtable, package_name, strlen(package_name), op_package);
-  
+
   return op_package;
 }
 
@@ -1838,18 +1818,11 @@ SPVM_OP* SPVM_OP_build_use(SPVM_COMPILER* compiler, SPVM_OP* op_use, SPVM_OP* op
   
   SPVM_OP_insert_child(compiler, op_use, op_use->last, op_type);
   
-  const char* package_name = op_type->uv.type->basic_type->name;
-  
   SPVM_USE* use = SPVM_USE_new(compiler);
   op_use->uv.use = use;
-  use->package_name = package_name;
+  use->op_type = op_type;
   
-  SPVM_OP* found_op_use = SPVM_HASH_search(compiler->op_use_symtable, package_name, strlen(package_name));
-  
-  if (!found_op_use) {
-    SPVM_LIST_push(compiler->op_use_stack, op_use);
-    SPVM_HASH_insert(compiler->op_use_symtable, package_name, strlen(package_name), op_use);
-  }
+  SPVM_LIST_push(compiler->op_use_stack, op_use);
   
   return op_use;
 }
@@ -2147,19 +2120,19 @@ SPVM_OP* SPVM_OP_build_enumeration_value(SPVM_COMPILER* compiler, SPVM_OP* op_na
     SPVM_CONSTANT* constant = op_constant->uv.constant;
     
     if (constant->type->dimension == 0 && constant->type->basic_type->id == SPVM_BASIC_TYPE_C_ID_INT) {
-      compiler->enum_default_value = constant->value.int_value;
+      compiler->current_enum_value = constant->value.int_value;
     }
     else {
       SPVM_yyerror_format(compiler, "enum value must be int type at %s line %d\n", op_constant->file, op_constant->line);
       return NULL;
     }
     
-    compiler->enum_default_value++;
+    compiler->current_enum_value++;
   }
   else {
-    op_constant = SPVM_OP_new_op_constant_int(compiler, (int32_t)compiler->enum_default_value, op_name->file, op_name->line);
+    op_constant = SPVM_OP_new_op_constant_int(compiler, (int32_t)compiler->current_enum_value, op_name->file, op_name->line);
     
-    compiler->enum_default_value++;
+    compiler->current_enum_value++;
   }
   
   // Return
@@ -2203,7 +2176,7 @@ SPVM_OP* SPVM_OP_build_enumeration(SPVM_COMPILER* compiler, SPVM_OP* op_enumerat
   SPVM_OP_insert_child(compiler, op_enumeration, op_enumeration->last, op_enumeration_block);
   
   // Reset enum information
-  compiler->enum_default_value = 0;
+  compiler->current_enum_value = 0;
   
   return op_enumeration;
 }
@@ -2531,7 +2504,7 @@ SPVM_OP* SPVM_OP_new_op_void(SPVM_COMPILER* compiler, const char* file, int32_t
   // Type op
   SPVM_OP* op_type = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_TYPE, file, line);
   
-  op_type->uv.type = SPVM_TYPE_get_void_type(compiler);
+  op_type->uv.type = SPVM_TYPE_create_void_type(compiler);
   
   return op_type;
 }
@@ -2544,31 +2517,8 @@ SPVM_OP* SPVM_OP_build_basic_type(SPVM_COMPILER* compiler, SPVM_OP* op_name) {
   SPVM_OP* op_type = SPVM_OP_new_op(compiler, SPVM_OP_C_ID_TYPE, op_name->file, op_name->line);
   SPVM_OP_insert_child(compiler, op_type, op_type->last, op_name);
   
-  if (strcmp(name, "byte") == 0) {
-    op_type->uv.type = SPVM_TYPE_get_byte_type(compiler);
-  }
-  else if (strcmp(name, "short") == 0) {
-    op_type->uv.type = SPVM_TYPE_get_short_type(compiler);
-  }
-  else if (strcmp(name, "int") == 0) {
-    op_type->uv.type = SPVM_TYPE_get_int_type(compiler);
-  }
-  else if (strcmp(name, "long") == 0) {
-    op_type->uv.type = SPVM_TYPE_get_long_type(compiler);
-  }
-  else if (strcmp(name, "float") == 0) {
-    op_type->uv.type = SPVM_TYPE_get_float_type(compiler);
-  }
-  else if (strcmp(name, "double") == 0) {
-    op_type->uv.type = SPVM_TYPE_get_double_type(compiler);
-  }
-  else {
-    SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-    op_type->uv.type = type;
-  }
-  
-  // Type
-  SPVM_TYPE* type = op_type->uv.type;
+  SPVM_TYPE* type = SPVM_TYPE_new(compiler);
+  op_type->uv.type = type;
   
   // Add types
   SPVM_LIST_push(compiler->op_types, op_type);
@@ -2581,7 +2531,6 @@ SPVM_OP* SPVM_OP_build_basic_type(SPVM_COMPILER* compiler, SPVM_OP* op_name) {
   else {
     SPVM_BASIC_TYPE* new_basic_type = SPVM_BASIC_TYPE_new(compiler);
     new_basic_type->id = compiler->basic_types->length;
-    new_basic_type->category = SPVM_BASIC_TYPE_C_CATEGORY_PACKAGE;
     new_basic_type->name = name;
     SPVM_LIST_push(compiler->basic_types, new_basic_type);
     SPVM_HASH_insert(compiler->basic_type_symtable, new_basic_type->name, strlen(new_basic_type->name), new_basic_type);
@@ -2632,7 +2581,7 @@ SPVM_OP* SPVM_OP_new_op_list(SPVM_COMPILER* compiler, const char* file, int32_t
 
 SPVM_OP* SPVM_OP_new_op(SPVM_COMPILER* compiler, int32_t id, const char* file, int32_t line) {
 
-  SPVM_OP *op = SPVM_COMPILER_ALLOCATOR_alloc_memory_pool(compiler, compiler->allocator, sizeof(SPVM_OP));
+  SPVM_OP *op = SPVM_COMPILER_ALLOCATOR_alloc_memory_pool(compiler, sizeof(SPVM_OP));
   
   memset(op, 0, sizeof(SPVM_OP));
   
