@@ -302,12 +302,12 @@ void SPVM_RUNTIME_API_weaken(SPVM_API* api, SPVM_OBJECT** object_address) {
   *object_address = (SPVM_OBJECT*)((intptr_t)*object_address | 1);
   
   // Create array of weaken_back_refs if need
-  if (object->uv.weaken_back_refs == NULL) {
-    object->uv.weaken_back_refs = SPVM_RUNTIME_API_new_address_array(api, 1);
-    object->uv.weaken_back_refs->ref_count++;
+  if (object->weaken_back_refs == NULL) {
+    object->weaken_back_refs = SPVM_RUNTIME_API_new_address_array(api, 1);
+    object->weaken_back_refs->ref_count++;
   }
   
-  int32_t capacity = object->uv.weaken_back_refs->length;
+  int32_t capacity = object->weaken_back_refs->units_length;
   int32_t length = object->weaken_back_refs_length;
   
   // Extend capacity
@@ -317,7 +317,7 @@ void SPVM_RUNTIME_API_weaken(SPVM_API* api, SPVM_OBJECT** object_address) {
     SPVM_OBJECT* new_weaken_back_refs = SPVM_RUNTIME_API_new_address_array(api, new_capacity);
     new_weaken_back_refs->ref_count++;
     
-    SPVM_OBJECT** weaken_back_refs_elements = (SPVM_OBJECT**)((intptr_t)object->uv.weaken_back_refs + sizeof(SPVM_OBJECT));
+    SPVM_OBJECT** weaken_back_refs_elements = (SPVM_OBJECT**)((intptr_t)object->weaken_back_refs + sizeof(SPVM_OBJECT));
     SPVM_OBJECT** new_weaken_back_refs_elements = (SPVM_OBJECT**)((intptr_t)new_weaken_back_refs + sizeof(SPVM_OBJECT));
     memcpy(new_weaken_back_refs_elements, weaken_back_refs_elements, length * sizeof(void*));
     
@@ -325,12 +325,12 @@ void SPVM_RUNTIME_API_weaken(SPVM_API* api, SPVM_OBJECT** object_address) {
     memset(weaken_back_refs_elements, 0, length * sizeof(void*));
     
     // Free old weaken back references
-    SPVM_RUNTIME_API_dec_ref_count(api, object->uv.weaken_back_refs);
+    SPVM_RUNTIME_API_dec_ref_count(api, object->weaken_back_refs);
     
-    object->uv.weaken_back_refs = new_weaken_back_refs;
+    object->weaken_back_refs = new_weaken_back_refs;
   }
   
-  SPVM_OBJECT*** weaken_back_refs_elements = (SPVM_OBJECT***)((intptr_t)object->uv.weaken_back_refs + sizeof(SPVM_OBJECT));
+  SPVM_OBJECT*** weaken_back_refs_elements = (SPVM_OBJECT***)((intptr_t)object->weaken_back_refs + sizeof(SPVM_OBJECT));
   weaken_back_refs_elements[length] = object_address;
   object->weaken_back_refs_length++;
 }
@@ -364,7 +364,7 @@ void SPVM_RUNTIME_API_unweaken(SPVM_API* api, SPVM_OBJECT** object_address) {
 
   int32_t length = object->weaken_back_refs_length;
   
-  SPVM_OBJECT*** weaken_back_refs_elements = (SPVM_OBJECT***)((intptr_t)object->uv.weaken_back_refs + sizeof(SPVM_OBJECT));
+  SPVM_OBJECT*** weaken_back_refs_elements = (SPVM_OBJECT***)((intptr_t)object->weaken_back_refs + sizeof(SPVM_OBJECT));
   
   {
     int32_t i;
@@ -420,9 +420,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_address_array(SPVM_API* api, int32_t length) {
   SPVM_OBJECT* object = SPVM_RUNTIME_ALLOCATOR_malloc_zero(api, allocator, array_byte_size);
   
   // Set array length
-  object->length = length;
+  object->units_length = length;
   
-  object->element_byte_size = sizeof(void*);
+  object->unit_byte_size = sizeof(void*);
   
   object->category = SPVM_OBJECT_C_CATEGORY_ADDRESS_ARRAY;
   
@@ -439,9 +439,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_call_stack_object(SPVM_API* api, int32_t lengt
   SPVM_OBJECT* object = SPVM_RUNTIME_ALLOCATOR_malloc_zero(api, allocator, array_byte_size);
   
   // Set array length
-  object->length = length;
+  object->units_length = length;
   
-  object->element_byte_size = sizeof(SPVM_API_VALUE);
+  object->unit_byte_size = sizeof(SPVM_API_VALUE);
   
   object->category = SPVM_OBJECT_C_CATEGORY_CALL_STACK;
   
@@ -464,9 +464,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_byte_array(SPVM_API* api, int32_t length) {
   object->basic_type_id = SPVM_BASIC_TYPE_C_ID_BYTE;
   
   // Set array length
-  object->length = length;
+  object->units_length = length;
   
-  object->element_byte_size = sizeof(int8_t);
+  object->unit_byte_size = sizeof(int8_t);
   
   object->category = SPVM_OBJECT_C_CATEGORY_NUMERIC_ARRAY;
   
@@ -489,9 +489,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_short_array(SPVM_API* api, int32_t length) {
   object->basic_type_id = SPVM_BASIC_TYPE_C_ID_SHORT;
   
   // Set array length
-  object->length = length;
+  object->units_length = length;
 
-  object->element_byte_size = sizeof(int16_t);
+  object->unit_byte_size = sizeof(int16_t);
 
   object->category = SPVM_OBJECT_C_CATEGORY_NUMERIC_ARRAY;
 
@@ -514,9 +514,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_int_array(SPVM_API* api, int32_t length) {
   object->basic_type_id = SPVM_BASIC_TYPE_C_ID_INT;
 
   // Set array length
-  object->length = length;
+  object->units_length = length;
 
-  object->element_byte_size = sizeof(int32_t);
+  object->unit_byte_size = sizeof(int32_t);
 
   object->category = SPVM_OBJECT_C_CATEGORY_NUMERIC_ARRAY;
   
@@ -539,9 +539,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_long_array(SPVM_API* api, int32_t length) {
   object->basic_type_id = SPVM_BASIC_TYPE_C_ID_LONG;
 
   // Set array length
-  object->length = length;
+  object->units_length = length;
 
-  object->element_byte_size = sizeof(int64_t);
+  object->unit_byte_size = sizeof(int64_t);
 
   object->category = SPVM_OBJECT_C_CATEGORY_NUMERIC_ARRAY;
   
@@ -564,9 +564,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_float_array(SPVM_API* api, int32_t length) {
   object->basic_type_id = SPVM_BASIC_TYPE_C_ID_FLOAT;
 
   // Set array length
-  object->length = length;
+  object->units_length = length;
 
-  object->element_byte_size = sizeof(float);
+  object->unit_byte_size = sizeof(float);
 
   object->category = SPVM_OBJECT_C_CATEGORY_NUMERIC_ARRAY;
   
@@ -589,9 +589,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_double_array(SPVM_API* api, int32_t length) {
   object->basic_type_id = SPVM_BASIC_TYPE_C_ID_DOUBLE;
   
   // Set array length
-  object->length = length;
+  object->units_length = length;
 
-  object->element_byte_size = sizeof(double);
+  object->unit_byte_size = sizeof(double);
 
   object->category = SPVM_OBJECT_C_CATEGORY_NUMERIC_ARRAY;
   
@@ -618,9 +618,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_object_array(SPVM_API* api, int32_t basic_type
   object->dimension = 1;
 
   // Set array length
-  object->length = length;
+  object->units_length = length;
   
-  object->element_byte_size = sizeof(SPVM_OBJECT*);
+  object->unit_byte_size = sizeof(SPVM_OBJECT*);
 
   object->category = SPVM_OBJECT_C_CATEGORY_OBJECT_ARRAY;
   
@@ -630,7 +630,6 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_object_array(SPVM_API* api, int32_t basic_type
 SPVM_OBJECT* SPVM_RUNTIME_API_new_multi_array(SPVM_API* api, int32_t basic_type_id, int32_t dimension, int32_t length) {
   
   SPVM_RUNTIME* runtime = SPVM_RUNTIME_API_get_runtime();
-  SPVM_COMPILER* compiler = runtime->compiler;
 
   SPVM_RUNTIME_ALLOCATOR* allocator = runtime->allocator;
   
@@ -645,9 +644,9 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_multi_array(SPVM_API* api, int32_t basic_type_
   object->dimension = dimension;
   
   // Set array length
-  object->length = length;
+  object->units_length = length;
   
-  object->element_byte_size = sizeof(SPVM_OBJECT*);
+  object->unit_byte_size = sizeof(SPVM_OBJECT*);
 
   object->category = SPVM_OBJECT_C_CATEGORY_OBJECT_ARRAY;
   
@@ -666,13 +665,19 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_object(SPVM_API* api, int32_t basic_type_id) {
   SPVM_OP* op_package = SPVM_HASH_search(compiler->op_package_symtable, basic_type->name, strlen(basic_type->name));
   SPVM_PACKAGE* package = op_package->uv.package;
   
+  int32_t length = package->op_fields->length;
+  int32_t element_byte_size = sizeof(SPVM_API_VALUE);
+  
   // Allocate memory
-  int64_t object_byte_size = (int64_t)sizeof(SPVM_OBJECT) + (int64_t)package->byte_size;
+  int64_t object_byte_size = (int64_t)sizeof(SPVM_OBJECT) + (int64_t)element_byte_size * length;
   SPVM_OBJECT* object = SPVM_RUNTIME_ALLOCATOR_malloc_zero(api, allocator, object_byte_size);
   
   object->basic_type_id = basic_type->id;
   object->dimension = 0;
-  
+
+  object->units_length = length;
+  object->unit_byte_size = element_byte_size;
+
   // Object type id
   object->category = SPVM_OBJECT_C_CATEGORY_OBJECT;
   
@@ -687,7 +692,7 @@ SPVM_OBJECT* SPVM_RUNTIME_API_new_object(SPVM_API* api, int32_t basic_type_id) {
 int32_t SPVM_RUNTIME_API_get_array_length(SPVM_API* api, SPVM_OBJECT* object) {
   (void)api;
   
-  return object->length;
+  return object->units_length;
 }
 
 SPVM_OBJECT* SPVM_RUNTIME_API_new_string(SPVM_API* api, int8_t* bytes, int32_t length) {
@@ -811,7 +816,7 @@ SPVM_OBJECT* SPVM_RUNTIME_API_get_object_array_accessent(SPVM_API* api, SPVM_OBJ
 
   assert(object);
   assert(index >= 0);
-  assert(index <= object->length);
+  assert(index <= object->units_length);
   
   SPVM_OBJECT* object_value = values[index];
   
@@ -825,7 +830,7 @@ void SPVM_RUNTIME_API_set_object_array_accessent(SPVM_API* api, SPVM_OBJECT* obj
   
   assert(object);
   assert(index >= 0);
-  assert(index <= object->length);
+  assert(index <= object->units_length);
   
   SPVM_RUNTIME_C_INLINE_OBJECT_ASSIGN(&values[index], object_value);
 }
@@ -887,7 +892,7 @@ void SPVM_RUNTIME_API_dec_ref_count(SPVM_API* api, SPVM_OBJECT* object) {
     }
     
     if (object->category == SPVM_OBJECT_C_CATEGORY_OBJECT_ARRAY) {
-      int32_t length = object->length;
+      int32_t length = object->units_length;
       {
         int32_t i;
         for (i = 0; i < length; i++) {
@@ -906,30 +911,23 @@ void SPVM_RUNTIME_API_dec_ref_count(SPVM_API* api, SPVM_OBJECT* object) {
       SPVM_PACKAGE* package = op_package->uv.package;
       
       {
-        int32_t field_index;
-        for (field_index = 0; field_index < package->op_fields->length; field_index++) {
-          SPVM_OP* op_field = SPVM_LIST_fetch(package->op_fields, field_index);
-          SPVM_FIELD* field = op_field->uv.field;
-          SPVM_TYPE* field_type = field->op_type->uv.type;
-          
-          if (SPVM_TYPE_is_object(compiler, field_type)) {
-            int32_t field_byte_offset = field->byte_offset;
-            
-            SPVM_OBJECT** object_field_address = (SPVM_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
-            if (*object_field_address != NULL) {
-              // If object is weak, unweaken
-              if (__builtin_expect(SPVM_RUNTIME_API_isweak(api, *object_field_address), 0)) {
-                SPVM_RUNTIME_API_unweaken(api, object_field_address);
-              }
-              else {
-                SPVM_RUNTIME_API_dec_ref_count(api, *object_field_address);
-              }
+        int32_t index;
+        for (index = 0; index < package->object_field_ids->length; index++) {
+          int32_t object_field_id = (intptr_t)SPVM_LIST_fetch(package->object_field_ids, index);
+          SPVM_OBJECT** object_field_address = (SPVM_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + sizeof(SPVM_API_VALUE) * object_field_id);
+          if (*object_field_address != NULL) {
+            // If object is weak, unweaken
+            if (__builtin_expect(SPVM_RUNTIME_API_isweak(api, *object_field_address), 0)) {
+              SPVM_RUNTIME_API_unweaken(api, object_field_address);
+            }
+            else {
+              SPVM_RUNTIME_API_dec_ref_count(api, *object_field_address);
             }
           }
         }
       }
-      if (__builtin_expect(object->uv.weaken_back_refs != NULL, 0)) {
-        SPVM_RUNTIME_API_free_weaken_back_refs(api, object->uv.weaken_back_refs, object->weaken_back_refs_length);
+      if (__builtin_expect(object->weaken_back_refs != NULL, 0)) {
+        SPVM_RUNTIME_API_free_weaken_back_refs(api, object->weaken_back_refs, object->weaken_back_refs_length);
       }
     }
     
@@ -1028,18 +1026,13 @@ int32_t SPVM_RUNTIME_API_get_field_id(SPVM_API* api, SPVM_OBJECT* object, const
   
   SPVM_LIST* op_fields = op_package->uv.package->op_fields;
   
-  int32_t field_id;
+  int32_t field_id = -1;
   {
-    int32_t field_index;
-    for (field_index = 0; field_index < op_fields->length; field_index++) {
-      SPVM_OP* op_field = SPVM_LIST_fetch(op_fields, field_index);
+    for (field_id = 0; field_id < op_fields->length; field_id++) {
+      SPVM_OP* op_field = SPVM_LIST_fetch(op_fields, field_id);
       SPVM_FIELD* field = op_field->uv.field;
       if (strcmp(name, field->op_name->uv.name) == 0) {
-        field_id = field->byte_offset;
-        break;
-      }
-      else {
-        field_id = -1;
+        return field->id;
       }
     }
   }
@@ -1135,7 +1128,7 @@ int32_t SPVM_RUNTIME_API_get_class_method_sub_id(SPVM_API* api, const char* pack
   return sub_id;
 }
 
-int8_t SPVM_RUNTIME_API_get_byte_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+int8_t SPVM_RUNTIME_API_get_byte_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_byte_field).");
@@ -1143,12 +1136,12 @@ int8_t SPVM_RUNTIME_API_get_byte_field(SPVM_API* api, SPVM_OBJECT* object, int32
     return 0;
   }
   
-  int8_t value = *(int8_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  int8_t value = *(int8_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
 
-int16_t SPVM_RUNTIME_API_get_short_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+int16_t SPVM_RUNTIME_API_get_short_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_short_field).");
@@ -1156,12 +1149,12 @@ int16_t SPVM_RUNTIME_API_get_short_field(SPVM_API* api, SPVM_OBJECT* object, int
     return 0;
   }
 
-  int16_t value = *(int16_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  int16_t value = *(int16_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
 
-int32_t SPVM_RUNTIME_API_get_int_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+int32_t SPVM_RUNTIME_API_get_int_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_int_field).");
@@ -1169,11 +1162,11 @@ int32_t SPVM_RUNTIME_API_get_int_field(SPVM_API* api, SPVM_OBJECT* object, int32
     return 0;
   }
 
-  int32_t value = *(int32_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  int32_t value = *(int32_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
-int64_t SPVM_RUNTIME_API_get_long_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+int64_t SPVM_RUNTIME_API_get_long_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_long_field).");
@@ -1181,12 +1174,12 @@ int64_t SPVM_RUNTIME_API_get_long_field(SPVM_API* api, SPVM_OBJECT* object, int3
     return 0;
   }
 
-  int64_t value = *(int64_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  int64_t value = *(int64_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
 
-float SPVM_RUNTIME_API_get_float_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+float SPVM_RUNTIME_API_get_float_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_float_field).");
@@ -1194,12 +1187,12 @@ float SPVM_RUNTIME_API_get_float_field(SPVM_API* api, SPVM_OBJECT* object, int32
     return 0;
   }
 
-  float value = *(float*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  float value = *(float*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
 
-double SPVM_RUNTIME_API_get_double_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+double SPVM_RUNTIME_API_get_double_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_double_field).");
@@ -1207,12 +1200,12 @@ double SPVM_RUNTIME_API_get_double_field(SPVM_API* api, SPVM_OBJECT* object, int
     return 0;
   }
 
-  double value = *(double*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  double value = *(double*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
 
-void SPVM_RUNTIME_API_weaken_object_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+void SPVM_RUNTIME_API_weaken_object_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(!object, 0)) {
     SPVM_OBJECT* exception = api->new_string_chars(api, "Object to weaken an object field must not be undefined.");
@@ -1220,7 +1213,7 @@ void SPVM_RUNTIME_API_weaken_object_field(SPVM_API* api, SPVM_OBJECT* object, in
     return;
   }
 
-  SPVM_OBJECT** object_address = (SPVM_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  SPVM_OBJECT** object_address = (SPVM_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   // Weaken object field
   if (*object_address != NULL) {
@@ -1230,7 +1223,7 @@ void SPVM_RUNTIME_API_weaken_object_field(SPVM_API* api, SPVM_OBJECT* object, in
   return;
 }
 
-SPVM_OBJECT* SPVM_RUNTIME_API_get_object_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset) {
+SPVM_OBJECT* SPVM_RUNTIME_API_get_object_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(get_object_field).");
@@ -1238,12 +1231,12 @@ SPVM_OBJECT* SPVM_RUNTIME_API_get_object_field(SPVM_API* api, SPVM_OBJECT* objec
     return NULL;
   }
 
-  SPVM_API_OBJECT* value = *(SPVM_API_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset);
+  SPVM_API_OBJECT* value = *(SPVM_API_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id);
   
   return value;
 }
 
-void SPVM_RUNTIME_API_set_byte_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, int8_t value) {
+void SPVM_RUNTIME_API_set_byte_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, int8_t value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_byte_field).");
@@ -1251,10 +1244,10 @@ void SPVM_RUNTIME_API_set_byte_field(SPVM_API* api, SPVM_OBJECT* object, int32_t
     return;
   }
 
-  *(int8_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset) = value;
+  *(int8_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id) = value;
 }
 
-void SPVM_RUNTIME_API_set_short_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, int16_t value) {
+void SPVM_RUNTIME_API_set_short_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, int16_t value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_short_field).");
@@ -1262,10 +1255,10 @@ void SPVM_RUNTIME_API_set_short_field(SPVM_API* api, SPVM_OBJECT* object, int32_
     return;
   }
 
-  *(int16_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset) = value;
+  *(int16_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id) = value;
 }
 
-void SPVM_RUNTIME_API_set_int_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, int32_t value) {
+void SPVM_RUNTIME_API_set_int_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, int32_t value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_int_field).");
@@ -1273,10 +1266,10 @@ void SPVM_RUNTIME_API_set_int_field(SPVM_API* api, SPVM_OBJECT* object, int32_t
     return;
   }
 
-  *(int32_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset) = value;
+  *(int32_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id) = value;
 }
 
-void SPVM_RUNTIME_API_set_long_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, int64_t value) {
+void SPVM_RUNTIME_API_set_long_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, int64_t value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_long_field).");
@@ -1284,10 +1277,10 @@ void SPVM_RUNTIME_API_set_long_field(SPVM_API* api, SPVM_OBJECT* object, int32_t
     return;
   }
 
-  *(int64_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset) = value;
+  *(int64_t*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id) = value;
 }
 
-void SPVM_RUNTIME_API_set_float_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, float value) {
+void SPVM_RUNTIME_API_set_float_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, float value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_float_field).");
@@ -1295,10 +1288,10 @@ void SPVM_RUNTIME_API_set_float_field(SPVM_API* api, SPVM_OBJECT* object, int32_
     return;
   }
   
-  *(float*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset) = value;
+  *(float*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id) = value;
 }
 
-void SPVM_RUNTIME_API_set_double_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, double value) {
+void SPVM_RUNTIME_API_set_double_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, double value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_double_field).");
@@ -1306,10 +1299,10 @@ void SPVM_RUNTIME_API_set_double_field(SPVM_API* api, SPVM_OBJECT* object, int32
     return;
   }
 
-  *(double*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset) = value;
+  *(double*)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id) = value;
 }
 
-void SPVM_RUNTIME_API_set_object_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_byte_offset, SPVM_OBJECT* value) {
+void SPVM_RUNTIME_API_set_object_field(SPVM_API* api, SPVM_OBJECT* object, int32_t field_id, SPVM_OBJECT* value) {
 
   if (__builtin_expect(object == NULL, 0)) {
     SPVM_OBJECT* exception = SPVM_RUNTIME_API_new_string_chars(api, "Object must be not undef(set_object_field).");
@@ -1317,7 +1310,7 @@ void SPVM_RUNTIME_API_set_object_field(SPVM_API* api, SPVM_OBJECT* object, int32
     return;
   }
   
-  SPVM_RUNTIME_C_INLINE_OBJECT_ASSIGN((SPVM_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_byte_offset), value);
+  SPVM_RUNTIME_C_INLINE_OBJECT_ASSIGN((SPVM_OBJECT**)((intptr_t)object + sizeof(SPVM_OBJECT) + field_id), value);
 }
 
 int32_t SPVM_RUNTIME_API_get_fields_length(SPVM_API* api, SPVM_OBJECT* object) {
