@@ -54,16 +54,16 @@ void SPVM_TYPE_sprint_type_name(SPVM_COMPILER* compiler, char* buffer, int32_t b
 }
 
 SPVM_TYPE* SPVM_TYPE_new(SPVM_COMPILER* compiler) {
-  SPVM_TYPE* type = SPVM_COMPILER_ALLOCATOR_alloc_memory_pool(compiler, compiler->allocator, sizeof(SPVM_TYPE));
+  SPVM_TYPE* type = SPVM_COMPILER_ALLOCATOR_alloc_memory_pool(compiler, sizeof(SPVM_TYPE));
   
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_void_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_void_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "void", strlen("void"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_VOID);
   type->dimension = 0;
   
   assert(type);
@@ -71,11 +71,11 @@ SPVM_TYPE* SPVM_TYPE_get_void_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_undef_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_undef_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "undef", strlen("undef"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_UNDEF);
   type->dimension = 0;
   
   assert(type);
@@ -83,7 +83,7 @@ SPVM_TYPE* SPVM_TYPE_get_undef_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_byte_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_byte_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
@@ -95,11 +95,11 @@ SPVM_TYPE* SPVM_TYPE_get_byte_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_short_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_short_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "short", strlen("short"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_SHORT);
   type->dimension = 0;
   
   assert(type);
@@ -107,11 +107,11 @@ SPVM_TYPE* SPVM_TYPE_get_short_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_int_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_int_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "int", strlen("int"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_INT);
   type->dimension = 0;
   
   assert(type);
@@ -119,11 +119,11 @@ SPVM_TYPE* SPVM_TYPE_get_int_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_long_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_long_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "long", strlen("long"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_LONG);
   type->dimension = 0;
   
   assert(type);
@@ -131,11 +131,11 @@ SPVM_TYPE* SPVM_TYPE_get_long_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_float_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_float_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "float", strlen("float"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_FLOAT);
   type->dimension = 0;
   
   assert(type);
@@ -143,11 +143,11 @@ SPVM_TYPE* SPVM_TYPE_get_float_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_double_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_double_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "double", strlen("double"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_DOUBLE);
   type->dimension = 0;
   
   assert(type);
@@ -155,11 +155,11 @@ SPVM_TYPE* SPVM_TYPE_get_double_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_string_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_string_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "String", strlen("String"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_STRING);
   type->dimension = 0;
   
   assert(type);
@@ -167,11 +167,11 @@ SPVM_TYPE* SPVM_TYPE_get_string_type(SPVM_COMPILER* compiler) {
   return type;
 }
 
-SPVM_TYPE* SPVM_TYPE_get_object_type(SPVM_COMPILER* compiler) {
+SPVM_TYPE* SPVM_TYPE_create_object_type(SPVM_COMPILER* compiler) {
   (void)compiler;
   
   SPVM_TYPE* type = SPVM_TYPE_new(compiler);
-  type->basic_type = SPVM_HASH_search(compiler->basic_type_symtable, "Object", strlen("Object"));
+  type->basic_type = SPVM_LIST_fetch(compiler->basic_types, SPVM_BASIC_TYPE_C_ID_ANY_OBJECT);
   type->dimension = 0;
   
   assert(type);
@@ -247,6 +247,8 @@ _Bool SPVM_TYPE_is_numeric(SPVM_COMPILER* compiler, SPVM_TYPE* type) {
 }
 
 _Bool SPVM_TYPE_equal(SPVM_COMPILER* compiler, SPVM_TYPE* type1, SPVM_TYPE* type2) {
+  (void)compiler;
+  
   if (type1->basic_type->id == type2->basic_type->id && type1->dimension == type2->dimension) {
     return 1;
   }
@@ -256,6 +258,7 @@ _Bool SPVM_TYPE_equal(SPVM_COMPILER* compiler, SPVM_TYPE* type1, SPVM_TYPE* type
 }
 
 _Bool SPVM_TYPE_is_int(SPVM_COMPILER* compiler, SPVM_TYPE* type) {
+  (void)compiler;
   
   if (type->dimension == 0 && type->basic_type->id == SPVM_BASIC_TYPE_C_ID_INT) {
     return 1;
