@@ -22,16 +22,16 @@ _Bool SPVM_TYPE_is_object(SPVM_COMPILER* compiler, SPVM_TYPE* type);
 _Bool SPVM_TYPE_is_any_object(SPVM_COMPILER* compiler, SPVM_TYPE* type);
 _Bool SPVM_TYPE_is_undef(SPVM_COMPILER* compiler, SPVM_TYPE* type);
 
-SPVM_TYPE* SPVM_TYPE_get_void_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_undef_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_byte_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_short_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_int_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_long_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_float_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_double_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_string_type(SPVM_COMPILER* compiler);
-SPVM_TYPE* SPVM_TYPE_get_object_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_void_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_undef_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_byte_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_short_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_int_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_long_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_float_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_double_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_string_type(SPVM_COMPILER* compiler);
+SPVM_TYPE* SPVM_TYPE_create_object_type(SPVM_COMPILER* compiler);
 
 _Bool SPVM_TYPE_equal(SPVM_COMPILER* compiler, SPVM_TYPE* type1, SPVM_TYPE* type2);
 
